==> egov-common-1.0.10-sources.jar: com/gtis/plat/vo/PfActivityVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfActivityVo implements Serializable {

    private static final long serialVersionUID = 1L;

    private String activityId;

    private String workflowInstanceId;

    private String activityName;

    private int activityState;

    private String priority;

    private Date beginTime;

    private Date finishTime;

    private int timeLimit;

    private String remark = "";

    private String activityDefinitionId;

    private String activityBefore = "";

    private int cooperatState;

    int handlesDay;

    boolean backState;

    private int top;

    private int left;

    private int width;

    private int height;

    private int backCount;

    private int isBack;

    private String organId;

    private int isRisk;

    public int getTop() {
        return top;
    }

    public void setTop(int top) {
        this.top = top;
    }

    public int getLeft() {
        return left;
    }

    public void setLeft(int left) {
        this.left = left;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public int getCooperatState() {
        return cooperatState;
    }

    public void setCooperatState(int cooperatState) {
        this.cooperatState = cooperatState;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getWorkflowInstanceId() {
        return workflowInstanceId;
    }

    public void setWorkflowInstanceId(String workflowInstanceId) {
        this.workflowInstanceId = workflowInstanceId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public int getActivityState() {
        return activityState;
    }

    public void setActivityState(int activityState) {
        this.activityState = activityState;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public int getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(int timeLimit) {
        this.timeLimit = timeLimit;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getActivityBefore() {
        return activityBefore;
    }

    public void setActivityBefore(String activityBefore) {
        this.activityBefore = activityBefore;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public int getBackCount() {
        return backCount;
    }

    public void setBackCount(int backCount) {
        this.backCount = backCount;
    }

    public int getIsBack() {
        return isBack;
    }

    public void setIsBack(int isBack) {
        this.isBack = isBack;
    }

    public String getOrganId() {
        return organId;
    }

    public void setOrganId(String organId) {
        this.organId = organId;
    }

    public int getRisk() {
        return isRisk;
    }

    public void setRisk(int risk) {
        isRisk = risk;
    }

    public int getBack() {
        return isBack;
    }

    public void setBack(int back) {
        isBack = back;
    }
}

==> egov-common-1.1.6-sources.jar: com/gtis/plat/vo/PfActivityVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfActivityVo implements Serializable {

    private static final long serialVersionUID = 1L;

    private String activityId;

    private String workflowInstanceId;

    private String activityName;

    private int activityState;

    private String priority;

    private Date beginTime;

    private Date finishTime;

    private String timeLimit;

    private String remark = "";

    private String activityDefinitionId;

    private String activityBefore = "";

    private int cooperatState;

    int handlesDay;

    boolean backState;

    private int top;

    private int left;

    private int width;

    private int height;

    private int backCount;

    private int isBack;

    private String organId;

    private int isRisk;

    public int getTop() {
        return top;
    }

    public void setTop(int top) {
        this.top = top;
    }

    public int getLeft() {
        return left;
    }

    public void setLeft(int left) {
        this.left = left;
    }

    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public int getCooperatState() {
        return cooperatState;
    }

    public void setCooperatState(int cooperatState) {
        this.cooperatState = cooperatState;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getWorkflowInstanceId() {
        return workflowInstanceId;
    }

    public void setWorkflowInstanceId(String workflowInstanceId) {
        this.workflowInstanceId = workflowInstanceId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public int getActivityState() {
        return activityState;
    }

    public void setActivityState(int activityState) {
        this.activityState = activityState;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(String timeLimit) {
        this.timeLimit = timeLimit;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getActivityBefore() {
        return activityBefore;
    }

    public void setActivityBefore(String activityBefore) {
        this.activityBefore = activityBefore;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public int getBackCount() {
        return backCount;
    }

    public void setBackCount(int backCount) {
        this.backCount = backCount;
    }

    public int getIsBack() {
        return isBack;
    }

    public void setIsBack(int isBack) {
        this.isBack = isBack;
    }

    public String getOrganId() {
        return organId;
    }

    public void setOrganId(String organId) {
        this.organId = organId;
    }

    public int getRisk() {
        return isRisk;
    }

    public void setRisk(int risk) {
        isRisk = risk;
    }

    public int getBack() {
        return isBack;
    }

    public void setBack(int back) {
        isBack = back;
    }
}
